@@ -9,7 +9,7 @@ use Text::WikiFormat::Blocks;
 use Scalar::Util qw( blessed reftype );
 
 use vars qw( $VERSION %tags $indent );
-$VERSION = '0.77'; 
+$VERSION = '0.81';
 $indent  = qr/^(?:\t+|\s{4,})/;
 %tags    = (
 	indent		=> qr/^(?:\t+|\s{4,})/,
@@ -34,13 +34,13 @@ $indent  = qr/^(?:\t+|\s{4,})/;
 	blocks		=> {
 		ordered		=> qr/^([\dA-Za-z]+)\.\s*/,
 		unordered	=> qr/^\*\s*/,
-		code		=> qr/  /,
+		code		=> qr/^(?:\t+|\s{4,})  /,
 		header      => qr/^(=+) (.+) \1/,
 		paragraph   => qr/^/,
 		line        => qr/^-{4,}/,
 	},
 
-	indented    => { map { $_ => 1 } qw( ordered unordered code )},
+	indented    => { map { $_ => 1 } qw( ordered unordered )},
 	nests       => { map { $_ => 1 } qw( ordered unordered ) },
 
 	blockorder               =>
@@ -84,6 +84,8 @@ sub merge_hash
 
 		$to->{$key} = $value;
 	}
+
+	return $to;
 }
 
 sub import
@@ -120,7 +122,8 @@ sub format
 
 	$opts    ||=
 	{
-		prefix => '', extended => 0, implicit_links => 1, absolute_links => 0
+		prefix => '', extended => 0, implicit_links => 1, absolute_links => 0,
+		nofollow_extended => 0
 	};
 
 	my %tags   = %tags;
@@ -157,7 +160,7 @@ sub find_blocks
 	my ($text, $tags, $opts) = @_;
 
 	my @blocks;
-	for my $line ( split(/\n/, $text) )
+	for my $line ( split(/\r?\n/, $text) )
 	{
 		my $block = start_block( $line, $tags, $opts );
 		push @blocks, $block if $block;
@@ -182,14 +185,6 @@ sub start_block
 		}
 
 		my $marker_removed = length ($line =~ s/$tags->{blocks}{$block}//);
-		if ($block eq 'code')
-		{
-			$level          = 0;
-			$marker_removed = 1;
-
-			# don't remove the indent, but do remove the code indent
-			($line = $text) =~ s/$tags->{blocks}{code}//;
-		}
 
 		next unless $marker_removed;
 
@@ -212,6 +207,8 @@ BEGIN
 		*{ $op . '_blocks' } = sub
 		{
 			my $blocks    = shift;
+			return unless @$blocks;
+
 			my @processed = shift @$blocks;
 
 			for my $block (@$blocks)
@@ -326,7 +323,7 @@ sub find_extended_links
 	my ($text, $tags, $opts) = @_;
 
     my $schemas = join('|', @{$tags->{schemas}});
-    $text =~ s!(\s+)(($schemas):\S+)!$1 . $tags->{link}->($2, $opts)!egi
+    $text =~ s!(^|\s+)(($schemas):\S+)!$1 . $tags->{link}->($2, $opts)!egi
 	    if $opts->{absolute_links};
 
 	my ($start, $end) = @{ $tags->{extended_link_delimiters} };
@@ -352,7 +349,10 @@ sub make_html_link
 	my $prefix               = ( defined $opts->{prefix} && $is_relative )
 		? $opts->{prefix} : '';
 
-	return qq|<a href="$prefix$link">$title</a>|;
+	my $nofollow             = (!$is_relative && $opts->{nofollow_extended})
+		? ' rel="nofollow"' : '';
+
+	return qq|<a href="$prefix$link"$nofollow>$title</a>|;
 }
 
 sub escape_link
@@ -461,6 +461,11 @@ earlier.
 The recognized schemas are those defined in the C<schema> value in the C<%tags>
 hash. The defaults are C<http>, C<https>, C<ftp>, C<mailto>, and C<gopher>.
 
+=item * nofollow_extended
+
+When used with the C<extended> flag, any extended links will be turned into HTML
+tags with the C<rel="nofollow"> attribute. By default, this option is off.
+
 =back
 
 =head2 Wiki Format
@@ -743,5 +748,5 @@ Matt Sergeant keeps threatening to write a nice SAX-throwing Wiki formatter.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2005, chromatic.  All rights reserved.  This module is
+Copyright (c) 2002 - 2006, chromatic.  All rights reserved.  This module is
 distributed under the same terms as Perl itself.
